import type { BuilderScreen } from "@/lib/admin/builder/types";
import { 
  buildDefaultHeader,
  buildDefaultTitle,
  buildDefaultSubtitle,
  buildDefaultBottomActionButton,
  buildDefaultNavigation,
  buildDefaultImage, 
  buildDefaultEmailInput 
} from "./blocks";

export function buildEmailDefaults(id: string): BuilderScreen {
  return {
    id,
    template: "email",
    header: buildDefaultHeader(),
    title: buildDefaultTitle({
      text: "Портрет твоей второй половинки готов! Куда нам его отправить?",
      align: "center",
    }),
    subtitle: buildDefaultSubtitle({
      show: false,
      text: undefined,
    }),
    image: buildDefaultImage(),
    emailInput: buildDefaultEmailInput(),
    bottomActionButton: buildDefaultBottomActionButton({
      showPrivacyTermsConsent: true
    }),
    navigation: buildDefaultNavigation(),
    variants: [
      {
        conditions: [],
        overrides: {
          image: buildDefaultImage({ src: "/male-portrait.jpg" }),
        },
      },
    ],
  } as BuilderScreen;
}
